<?php

namespace App\Http;

use Illuminate\Foundation\Http\Kernel as HttpKernel;

class Kernel extends HttpKernel
{
    /**
     * The application's global HTTP middleware stack.
     *
     * These middleware are run during every request to your application.
     *
     * @var array<int, class-string|string>
     */
    protected $middleware = [
        // \App\Http\Middleware\TrustHosts::class,
        \App\Http\Middleware\TrustProxies::class,
        \Illuminate\Http\Middleware\HandleCors::class,
        \App\Http\Middleware\PreventRequestsDuringMaintenance::class,
        \Illuminate\Foundation\Http\Middleware\ValidatePostSize::class,
        \App\Http\Middleware\TrimStrings::class,
        \Illuminate\Foundation\Http\Middleware\ConvertEmptyStringsToNull::class,
    ];

    /**
     * The application's route middleware groups.
     *
     * @var array<string, array<int, class-string|string>>
     */
    protected $middlewareGroups = [
        'public' => [
            \App\Http\Middleware\EncryptCookies::class,
            \Illuminate\Cookie\Middleware\AddQueuedCookiesToResponse::class,
            \Illuminate\Session\Middleware\StartSession::class,
            \Illuminate\View\Middleware\ShareErrorsFromSession::class,
            \App\Http\Middleware\VerifyCsrfToken::class,
            \Illuminate\Routing\Middleware\SubstituteBindings::class,
            \TypiCMS\Modules\Core\Http\Middleware\Impersonate::class,
            \TypiCMS\Modules\Core\Http\Middleware\SetNavbarLocale::class,

            \TypiCMS\Modules\Core\Http\Middleware\VerifyLocalizedUrl::class,
            \TypiCMS\Modules\Core\Http\Middleware\SetLocaleFromUrl::class,
            \TypiCMS\Modules\Core\Http\Middleware\SetSystemLocale::class,
            \TypiCMS\Modules\Core\Http\Middleware\PublicAccess::class,
        ],

        'admin' => [
            \App\Http\Middleware\EncryptCookies::class,
            \Illuminate\Cookie\Middleware\AddQueuedCookiesToResponse::class,
            \Illuminate\Session\Middleware\StartSession::class,
            \Illuminate\View\Middleware\ShareErrorsFromSession::class,
            \App\Http\Middleware\VerifyCsrfToken::class,

            'auth',

            \TypiCMS\Modules\Core\Http\Middleware\SetTranslatableFallbackLocaleToNull::class,
            \TypiCMS\Modules\Core\Http\Middleware\SetLocaleFromUser::class,
            \TypiCMS\Modules\Core\Http\Middleware\SetContentLocale::class,
            \TypiCMS\Modules\Core\Http\Middleware\SetSystemLocale::class,

            \Illuminate\Routing\Middleware\SubstituteBindings::class,
            \TypiCMS\Modules\Core\Http\Middleware\Impersonate::class,
            \TypiCMS\Modules\Core\Http\Middleware\SetNavbarLocale::class,

            \TypiCMS\Modules\Core\Http\Middleware\JavaScriptData::class,
            \TypiCMS\Modules\Core\Http\Middleware\UserPrefs::class,
        ],

        'api' => [
            'throttle:api',
            \TypiCMS\Modules\Core\Http\Middleware\SetLocaleFromUser::class,
            \Illuminate\Routing\Middleware\SubstituteBindings::class,
        ],
    ];

    /**
     * The application's route middleware.
     *
     * These middleware may be assigned to groups or used individually.
     *
     * @var array<string, class-string|string>
     */
    protected $routeMiddleware = [
        'auth' => \App\Http\Middleware\Authenticate::class,
        'auth.basic' => \Illuminate\Auth\Middleware\AuthenticateWithBasicAuth::class,
        'auth.session' => \Illuminate\Session\Middleware\AuthenticateSession::class,
        'cache.headers' => \Illuminate\Http\Middleware\SetCacheHeaders::class,
        'can' => \Illuminate\Auth\Middleware\Authorize::class,
        'guest' => \App\Http\Middleware\RedirectIfAuthenticated::class,
        'password.confirm' => \Illuminate\Auth\Middleware\RequirePassword::class,
        'signed' => \Illuminate\Routing\Middleware\ValidateSignature::class,
        'throttle' => \Illuminate\Routing\Middleware\ThrottleRequests::class,
        'verified' => \Illuminate\Auth\Middleware\EnsureEmailIsVerified::class,
    ];
}
